@@ -3,10 +3,11 @@ package Travel::Routing::DE::EFA;
 use strict;
 use warnings;
 use 5.010;
+use utf8;
 
 no if $] >= 5.018, warnings => "experimental::smartmatch";
 
-use Carp qw(cluck);
+use Carp   qw(cluck);
 use Encode qw(encode);
 use Travel::Routing::DE::EFA::Route;
 use Travel::Routing::DE::EFA::Route::Message;
@@ -41,7 +42,7 @@ use Exception::Class (
 	},
 );
 
-our $VERSION = '2.17';
+our $VERSION = '2.21';
 
 sub set_time {
 	my ( $self, %conf ) = @_;
@@ -681,6 +682,7 @@ sub parse_xml_part {
 			departure_stime    => $self->itdtime_str($e_dstime),
 			departure_stop     => $e_dep->getAttribute('name'),
 			departure_platform => $e_dep->getAttribute('platformName'),
+			occupancy          => $e_dep->getAttribute('occupancy'),
 			train_line         => $e_mot->getAttribute('name'),
 			train_product      => $e_mot->getAttribute('productName'),
 			train_destination  => $e_mot->getAttribute('destination'),
@@ -818,7 +820,7 @@ sub check_ambiguous_xml {
 
 	if ( $s_place eq 'list' ) {
 		Travel::Routing::DE::EFA::Exception::Ambiguous->throw(
-			post_key => 'place',
+			post_key   => 'place',
 			post_value =>
 			  ( $e_place->findnodes($xp_place_input) )[0]->textContent,
 			possibilities => join( q{ | },
@@ -828,7 +830,7 @@ sub check_ambiguous_xml {
 	}
 	if ( $s_name eq 'list' ) {
 		Travel::Routing::DE::EFA::Exception::Ambiguous->throw(
-			post_key => 'name',
+			post_key   => 'name',
 			post_value =>
 			  ( $e_name->findnodes($xp_name_input) )[0]->textContent,
 			possibilities => join( q{ | },
@@ -839,13 +841,15 @@ sub check_ambiguous_xml {
 	if ( $s_place eq 'notidentified' ) {
 		Travel::Routing::DE::EFA::Exception::Setup->throw(
 			option => 'place',
-			error  => 'unknown place (typo?)'
+			error  => 'unknown place',
+			have   => ( $e_place->findnodes($xp_place_input) )[0]->textContent,
 		);
 	}
 	if ( $s_name eq 'notidentified' ) {
 		Travel::Routing::DE::EFA::Exception::Setup->throw(
 			option => 'name',
-			error  => 'unknown name (typo?)'
+			error  => 'unknown name',
+			have   => ( $e_name->findnodes($xp_name_input) )[0]->textContent,
 		);
 	}
 
@@ -862,99 +866,85 @@ sub routes {
 
 # static
 sub get_efa_urls {
+
+	# sorted lexically by shortname
 	return (
 		{
-			url       => 'http://www.ding.eu/ding3/XSLT_TRIP_REQUEST2',
+			url       => 'https://bsvg.efa.de/bsvagstd/XML_TRIP_REQUEST2',
+			name      => 'Braunschweiger Verkehrs-GmbH',
+			shortname => 'BSVG',
+		},
+		{
+			url       => 'https://www.ding.eu/ding3/XSLT_TRIP_REQUEST2',
 			name      => 'Donau-Iller Nahverkehrsverbund',
 			shortname => 'DING',
 		},
 		{
-			url       => 'http://efa.ivb.at/ivb/XSLT_TRIP_REQUEST2',
-			name      => 'Innsbrucker Verkehrsbetriebe',
-			shortname => 'IVB',
+			url  => 'https://projekte.kvv-efa.de/sl3-alone/XSLT_TRIP_REQUEST2',
+			name => 'Karlsruher Verkehrsverbund',
+			shortname => 'KVV',
 		},
 		{
-			url       => 'http://efa.svv-info.at/sbs/XSLT_TRIP_REQUEST2',
-			name      => 'Salzburger Verkehrsverbund',
-			shortname => 'SVV',
-		},
-		{
-			url       => 'http://efa.vor.at/wvb/XSLT_TRIP_REQUEST2',
-			name      => 'Verkehrsverbund Ost-Region',
-			shortname => 'VOR',
-		},
-
-		# Returns broken Unicode which makes Encode::decode die()
-		#{
-		#	url  => 'http://fahrplan.verbundlinie.at/stv/XSLT_TRIP_REQUEST2',
-		#	name => 'Verkehrsverbund Steiermark',
-		#	shortname => 'Verbundlinie',
-		#},
-		{
-			url       => 'http://www.linzag.at/static/XSLT_TRIP_REQUEST2',
+			url       => 'https://www.linzag.at/static/XSLT_TRIP_REQUEST2',
 			name      => 'Linz AG',
 			shortname => 'LinzAG',
 		},
 		{
-			url       => 'http://212.114.197.7/vgnExt_oeffi/XML_TRIP_REQUEST2',
+			url  => 'https://efa.mvv-muenchen.de/mobile/XSLT_TRIP_REQUEST2',
+			name => 'Münchner Verkehrs- und Tarifverbund',
+			shortname => 'MVV',
+		},
+		{
+			url       => 'https://www.efa-bw.de/nvbw/XSLT_TRIP_REQUEST2',
+			name      => 'Nahverkehrsgesellschaft Baden-Württemberg',
+			shortname => 'NVBW',
+		},
+		{
+			url       => 'https://efa.vagfr.de/vagfr3/XSLT_TRIP_REQUEST2',
+			name      => 'Freiburger Verkehrs AG',
+			shortname => 'VAG',
+		},
+		{
+			url       => 'https://efa.vgn.de/vgnExt_oeffi/XML_TRIP_REQUEST2',
 			name      => 'Verkehrsverbund Grossraum Nuernberg',
 			shortname => 'VGN',
 		},
+
+		# HTTPS: certificate verification fails
 		{
-			url       => 'http://efa.vrr.de/vrr/XSLT_TRIP_REQUEST2',
-			name      => 'Verkehrsverbund Rhein-Ruhr',
-			shortname => 'VRR',
-		},
-		{
-			url       => 'http://app.vrr.de/vrrstd/XML_TRIP_REQUEST2',
-			name      => 'Verkehrsverbund Rhein-Ruhr (alternative)',
-			shortname => 'VRR2',
-		},
-		{
-			url       => 'http://www2.vvs.de/vvs/XSLT_TRIP_REQUEST2',
-			name      => 'Verkehrsverbund Stuttgart',
-			shortname => 'VVS',
-		},
-		{
-			url => 'http://delfi1.vvo-online.de:8080/delfi3/XSLT_TRIP_REQUEST2',
-			name      => 'Verkehrsverbund Oberelbe',
-			shortname => 'VVO',
-		},
-		{
-			url       => 'http://delfi.vrn.de/delfi/XSLT_TRIP_REQUEST2',
-			name      => 'Verkehrsverbund Rhein-Neckar (DELFI)',
-			shortname => 'VRNdelfi',
-		},
-		{
-			url       => 'http://fahrplanauskunft.vrn.de/vrn/XML_TRIP_REQUEST2',
-			name      => 'Verkehrsverbund Rhein-Neckar',
-			shortname => 'VRN',
-		},
-		{
-			url       => 'http://80.146.180.107/vmv/XSLT_TRIP_REQUEST2',
+			url       => 'http://efa.vmv-mbh.de/vmv/XML_TRIP_REQUEST2',
 			name      => 'Verkehrsgesellschaft Mecklenburg-Vorpommern',
 			shortname => 'VMV',
 		},
 		{
-			url       => 'http://213.144.24.66/kvv2/XML_TRIP_REQUEST2',
-			name      => 'Karlsruher Verkehrsverbund',
-			shortname => 'KVV',
+			url       => 'https://www.vrn.de/mngvrn/XML_TRIP_REQUEST2',
+			name      => 'Verkehrsverbund Rhein-Neckar',
+			shortname => 'VRN',
 		},
 		{
-			url =>
-			  'http://www.travelineeastmidlands.co.uk/em/XSLT_TRIP_REQUEST2',
-			name      => 'Traveline East Midlands',
-			shortname => 'TLEM',
+			url       => 'https://efa.vrr.de/vrr/XSLT_TRIP_REQUEST2',
+			name      => 'Verkehrsverbund Rhein-Ruhr',
+			shortname => 'VRR',
 		},
 		{
-			url       => 'http://mobil.vbl.ch/vblmobil/XML_TRIP_REQUEST2',
-			name      => 'Verkehrsbetriebe Luzern',
-			shortname => 'VBL',
+			url       => 'https://app.vrr.de/vrrstd/XML_TRIP_REQUEST2',
+			name      => 'Verkehrsverbund Rhein-Ruhr (alternative)',
+			shortname => 'VRR2',
 		},
 		{
-			url       => 'http://bsvg.efa.de/bsvagstd/XML_TRIP_REQUEST2',
-			name      => 'Braunschweiger Verkehrs-GmbH',
-			shortname => 'BSVG',
+			url       => 'https://efa.vrr.de/rbgstd3/XSLT_TRIP_REQUEST2',
+			name      => 'Verkehrsverbund Rhein-Ruhr (alternative alternative)',
+			shortname => 'VRR3',
+		},
+		{
+			url       => 'https://efa.vvo-online.de/VMSSL3/XSLT_TRIP_REQUEST2',
+			name      => 'Verkehrsverbund Oberelbe',
+			shortname => 'VVO',
+		},
+		{
+			url       => 'https://www2.vvs.de/vvs/XSLT_TRIP_REQUEST2',
+			name      => 'Verkehrsverbund Stuttgart',
+			shortname => 'VVS',
 		},
 	);
 }
@@ -991,7 +981,7 @@ Travel::Routing::DE::EFA - unofficial interface to EFA-based itinerary services
 
 =head1 VERSION
 
-version 2.17
+version 2.21
 
 =head1 DESCRIPTION
 
@@ -1262,8 +1252,8 @@ None known.
 
 =head1 AUTHOR
 
-Copyright (C) 2009-2018 by Daniel Friesel E<lt>derf@finalrewind.orgE<gt>
+Copyright (C) 2009-2023 by Birte Kristina Friesel E<lt>derf@finalrewind.orgE<gt>
 
 =head1 LICENSE
 
-  0. You just DO WHAT THE FUCK YOU WANT TO.
+This program is licensed under the same terms as Perl itself.
